@@ -219,7 +219,7 @@ class JinjaStaticRenderer():
                 template=page.get_page_vars()
                 )
             new_file = open(new_file_path, "w")
-            new_file.write(html)
+            new_file.write(html.encode('utf8'))
             self.print_stdout(page.get_file_path(), new_file_path, template)
             file_did_render = 1
 
