@@ -20,7 +20,7 @@ class Page():
 
     def get_contents(self, file_path):
         source_file = open(file_path, 'r')
-        file_contents = source_file.read()
+        file_contents = source_file.read().decode('utf8')
         return file_contents
 
     def get_metadata(self, file_contents):
